@@ -3,11 +3,12 @@ import torch.nn as nn
 from .utils import load_state_dict_from_url, load_state_dict
 
 
-__all__ = [ 'resnext101_32x8d']
+__all__ = [ 'resnext101_32x8d', 'resnet50']
 
 
 model_urls = {
     'resnext101_32x8d': "https://argusvision.blob.core.windows.net/imageencoder/ArgusVisionEncoder.V6.tar",
+    'resnet50': "https://argusvision.blob.core.windows.net/imageencoder/ResNet50.tar",
 }
 
 def conv3x3(in_planes, out_planes, stride=1, groups=1, dilation=1):
@@ -113,7 +114,7 @@ class Bottleneck(nn.Module):
 class ResNet(nn.Module):
 
     def __init__(self, block, layers, zero_init_residual=False,
-                 groups=32, width_per_group=8, replace_stride_with_dilation=None,
+                 groups=1, width_per_group=64, replace_stride_with_dilation=None,
                  norm_layer=None):
         super(ResNet, self).__init__()
         if norm_layer is None:
@@ -207,8 +208,8 @@ class ResNet(nn.Module):
         return self._forward_impl(x)
 
 
-def _resnet(arch, block, layers, pretrained, map_location):
-    model = ResNet(block, layers)
+def _resnet(arch, block, layers, pretrained, map_location, **kwargs):
+    model = ResNet(block, layers, **kwargs)
     if pretrained:
         print("Loading Argus Vision pretrained model")
         state_dict = load_state_dict_from_url(model_urls[arch], map_location)
@@ -225,5 +226,11 @@ def resnext101_32x8d(pretrained=True, map_location=None):
         pretrained (bool): If True, returns a model pre-trained on ImageNet
         progress (bool): If True, displays a progress bar of the download to stderr
     """
+    kwargs = {}
+    kwargs['groups'] = 32
+    kwargs['width_per_group'] = 8
     return _resnet('resnext101_32x8d', Bottleneck, [3, 4, 23, 3],
-                   pretrained, map_location)
+                   pretrained, map_location, **kwargs)
+
+def resnet50(pretrained=True, map_location=None):
+    return _resnet('resnet50', Bottleneck, [3, 4, 6, 3], pretrained, map_location)
\ No newline at end of file
